@@ -13,9 +13,7 @@ var growl = require('./nodejs/growl');
 var utils = require('./utils');
 var mocharc = require('./mocharc.json');
 var Suite = require('./suite');
-var esmUtils = utils.supportsEsModules(true)
-  ? require('./esm-utils')
-  : undefined;
+var esmUtils = require('./nodejs/esm-utils');
 var createStatsCollector = require('./stats-collector');
 const {
   warn,
@@ -25,12 +23,8 @@ const {
   createMochaInstanceAlreadyRunningError,
   createUnsupportedError
 } = require('./errors');
-const {
-  EVENT_FILE_PRE_REQUIRE,
-  EVENT_FILE_POST_REQUIRE,
-  EVENT_FILE_REQUIRE
-} = Suite.constants;
-var sQuote = utils.sQuote;
+const {EVENT_FILE_PRE_REQUIRE, EVENT_FILE_POST_REQUIRE, EVENT_FILE_REQUIRE} =
+  Suite.constants;
 var debug = require('debug')('mocha:mocha');
 
 exports = module.exports = Mocha;
@@ -96,6 +90,61 @@ exports.Suite = Suite;
 exports.Hook = require('./hook');
 exports.Test = require('./test');
 
+let currentContext;
+exports.afterEach = function (...args) {
+  return (currentContext.afterEach || currentContext.teardown).apply(
+    this,
+    args
+  );
+};
+exports.after = function (...args) {
+  return (currentContext.after || currentContext.suiteTeardown).apply(
+    this,
+    args
+  );
+};
+exports.beforeEach = function (...args) {
+  return (currentContext.beforeEach || currentContext.setup).apply(this, args);
+};
+exports.before = function (...args) {
+  return (currentContext.before || currentContext.suiteSetup).apply(this, args);
+};
+exports.describe = function (...args) {
+  return (currentContext.describe || currentContext.suite).apply(this, args);
+};
+exports.describe.only = function (...args) {
+  return (currentContext.describe || currentContext.suite).only.apply(
+    this,
+    args
+  );
+};
+exports.describe.skip = function (...args) {
+  return (currentContext.describe || currentContext.suite).skip.apply(
+    this,
+    args
+  );
+};
+exports.it = function (...args) {
+  return (currentContext.it || currentContext.test).apply(this, args);
+};
+exports.it.only = function (...args) {
+  return (currentContext.it || currentContext.test).only.apply(this, args);
+};
+exports.it.skip = function (...args) {
+  return (currentContext.it || currentContext.test).skip.apply(this, args);
+};
+exports.xdescribe = exports.describe.skip;
+exports.xit = exports.it.skip;
+exports.setup = exports.beforeEach;
+exports.suiteSetup = exports.before;
+exports.suiteTeardown = exports.after;
+exports.suite = exports.describe;
+exports.teardown = exports.afterEach;
+exports.test = exports.it;
+exports.run = function (...args) {
+  return currentContext.run.apply(this, args);
+};
+
 /**
  * Constructs a new Mocha instance with `options`.
  *
@@ -109,6 +158,8 @@ exports.Test = require('./test');
  * @param {boolean} [options.color] - Color TTY output from reporter?
  * @param {boolean} [options.delay] - Delay root suite execution?
  * @param {boolean} [options.diff] - Show diff on failure?
+ * @param {boolean} [options.dryRun] - Report tests without running them?
+ * @param {boolean} [options.failZero] - Fail test run if zero tests?
  * @param {string} [options.fgrep] - Test filter given string.
  * @param {boolean} [options.forbidOnly] - Tests marked `only` fail the suite?
  * @param {boolean} [options.forbidPending] - Pending tests fail the suite?
@@ -125,10 +176,10 @@ exports.Test = require('./test');
  * @param {number} [options.slow] - Slow threshold value.
  * @param {number|string} [options.timeout] - Timeout threshold value.
  * @param {string} [options.ui] - Interface name.
- * @param {boolean} [options.parallel] - Run jobs in parallel
- * @param {number} [options.jobs] - Max number of worker processes for parallel runs
- * @param {MochaRootHookObject} [options.rootHooks] - Hooks to bootstrap the root
- * suite with
+ * @param {boolean} [options.parallel] - Run jobs in parallel.
+ * @param {number} [options.jobs] - Max number of worker processes for parallel runs.
+ * @param {MochaRootHookObject} [options.rootHooks] - Hooks to bootstrap the root suite with.
+ * @param {string[]} [options.require] - Pathname of `rootHooks` plugin for parallel runs.
  * @param {boolean} [options.isWorker] - Should be `true` if `Mocha` process is running in a worker process.
  */
 function Mocha(options = {}) {
@@ -145,7 +196,7 @@ function Mocha(options = {}) {
     .ui(options.ui)
     .reporter(
       options.reporter,
-      options.reporterOption || options.reporterOptions // reporterOptions was previously the only way to specify options to reporter
+      options.reporterOption || options.reporterOptions // for backwards compability
     )
     .slow(options.slow)
     .global(options.global);
@@ -167,13 +218,15 @@ function Mocha(options = {}) {
     'color',
     'delay',
     'diff',
+    'dryRun',
+    'failZero',
     'forbidOnly',
     'forbidPending',
     'fullTrace',
     'growl',
     'inlineDiffs',
     'invert'
-  ].forEach(function(opt) {
+  ].forEach(function (opt) {
     if (options[opt]) {
       this[opt]();
     }
@@ -231,7 +284,7 @@ function Mocha(options = {}) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.bail = function(bail) {
+Mocha.prototype.bail = function (bail) {
   this.suite.bail(bail !== false);
   return this;
 };
@@ -249,7 +302,7 @@ Mocha.prototype.bail = function(bail) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.addFile = function(file) {
+Mocha.prototype.addFile = function (file) {
   this.files.push(file);
   return this;
 };
@@ -270,7 +323,7 @@ Mocha.prototype.addFile = function(file) {
  * // Use XUnit reporter and direct its output to file
  * mocha.reporter('xunit', { output: '/path/to/testspec.xunit.xml' });
  */
-Mocha.prototype.reporter = function(reporterName, reporterOptions) {
+Mocha.prototype.reporter = function (reporterName, reporterOptions) {
   if (typeof reporterName === 'function') {
     this._reporter = reporterName;
   } else {
@@ -291,23 +344,19 @@ Mocha.prototype.reporter = function(reporterName, reporterOptions) {
             reporter = require(path.resolve(utils.cwd(), reporterName));
           } catch (_err) {
             _err.code === 'MODULE_NOT_FOUND'
-              ? warn(sQuote(reporterName) + ' reporter not found')
+              ? warn(`'${reporterName}' reporter not found`)
               : warn(
-                  sQuote(reporterName) +
-                    ' reporter blew up with error:\n' +
-                    err.stack
+                  `'${reporterName}' reporter blew up with error:\n ${err.stack}`
                 );
           }
         } else {
-          warn(
-            sQuote(reporterName) + ' reporter blew up with error:\n' + err.stack
-          );
+          warn(`'${reporterName}' reporter blew up with error:\n ${err.stack}`);
         }
       }
     }
     if (!reporter) {
       throw createInvalidReporterError(
-        'invalid reporter ' + sQuote(reporterName),
+        `invalid reporter '${reporterName}'`,
         reporterName
       );
     }
@@ -330,7 +379,7 @@ Mocha.prototype.reporter = function(reporterName, reporterOptions) {
  * @chainable
  * @throws {Error} if requested interface cannot be loaded
  */
-Mocha.prototype.ui = function(ui) {
+Mocha.prototype.ui = function (ui) {
   var bindInterface;
   if (typeof ui === 'function') {
     bindInterface = ui;
@@ -341,30 +390,14 @@ Mocha.prototype.ui = function(ui) {
       try {
         bindInterface = require(ui);
       } catch (err) {
-        throw createInvalidInterfaceError(
-          'invalid interface ' + sQuote(ui),
-          ui
-        );
+        throw createInvalidInterfaceError(`invalid interface '${ui}'`, ui);
       }
     }
   }
   bindInterface(this.suite);
 
-  this.suite.on(EVENT_FILE_PRE_REQUIRE, function(context) {
-    exports.afterEach = context.afterEach || context.teardown;
-    exports.after = context.after || context.suiteTeardown;
-    exports.beforeEach = context.beforeEach || context.setup;
-    exports.before = context.before || context.suiteSetup;
-    exports.describe = context.describe || context.suite;
-    exports.it = context.it || context.test;
-    exports.xit = context.xit || (context.test && context.test.skip);
-    exports.setup = context.setup || context.beforeEach;
-    exports.suiteSetup = context.suiteSetup || context.before;
-    exports.suiteTeardown = context.suiteTeardown || context.after;
-    exports.suite = context.suite || context.describe;
-    exports.teardown = context.teardown || context.afterEach;
-    exports.test = context.test || context.it;
-    exports.run = context.run;
+  this.suite.on(EVENT_FILE_PRE_REQUIRE, function (context) {
+    currentContext = context;
   });
 
   return this;
@@ -385,10 +418,10 @@ Mocha.prototype.ui = function(ui) {
  * @see {@link Mocha#loadFilesAsync}
  * @param {Function} [fn] - Callback invoked upon completion.
  */
-Mocha.prototype.loadFiles = function(fn) {
+Mocha.prototype.loadFiles = function (fn) {
   var self = this;
   var suite = this.suite;
-  this.files.forEach(function(file) {
+  this.files.forEach(function (file) {
     file = path.resolve(file);
     suite.emit(EVENT_FILE_PRE_REQUIRE, global, file, self);
     suite.emit(EVENT_FILE_REQUIRE, require(file), file, self);
@@ -417,23 +450,17 @@ Mocha.prototype.loadFiles = function(fn) {
  *   .then(() => mocha.run(failures => process.exitCode = failures ? 1 : 0))
  *   .catch(() => process.exitCode = 1);
  */
-Mocha.prototype.loadFilesAsync = function() {
+Mocha.prototype.loadFilesAsync = function () {
   var self = this;
   var suite = this.suite;
   this.lazyLoadFiles(true);
 
-  if (!esmUtils) {
-    return new Promise(function(resolve) {
-      self.loadFiles(resolve);
-    });
-  }
-
   return esmUtils.loadFilesAsync(
     this.files,
-    function(file) {
+    function (file) {
       suite.emit(EVENT_FILE_PRE_REQUIRE, global, file, self);
     },
-    function(file, resultModule) {
+    function (file, resultModule) {
       suite.emit(EVENT_FILE_REQUIRE, resultModule, file, self);
       suite.emit(EVENT_FILE_POST_REQUIRE, global, file, self);
     }
@@ -448,7 +475,7 @@ Mocha.prototype.loadFilesAsync = function() {
  * @see {@link Mocha#unloadFiles}
  * @param {string} file - Pathname of file to be unloaded.
  */
-Mocha.unloadFile = function(file) {
+Mocha.unloadFile = function (file) {
   if (utils.isBrowser()) {
     throw createUnsupportedError(
       'unloadFile() is only suported in a Node.js environment'
@@ -472,7 +499,7 @@ Mocha.unloadFile = function(file) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.unloadFiles = function() {
+Mocha.prototype.unloadFiles = function () {
   if (this._state === mochaStates.DISPOSED) {
     throw createMochaInstanceAlreadyDisposedError(
       'Mocha instance is already disposed, it cannot be used again.',
@@ -481,7 +508,7 @@ Mocha.prototype.unloadFiles = function() {
     );
   }
 
-  this.files.forEach(function(file) {
+  this.files.forEach(function (file) {
     Mocha.unloadFile(file);
   });
   this._state = mochaStates.INIT;
@@ -501,7 +528,7 @@ Mocha.prototype.unloadFiles = function() {
  * // Select tests whose full title begins with `"foo"` followed by a period
  * mocha.fgrep('foo.');
  */
-Mocha.prototype.fgrep = function(str) {
+Mocha.prototype.fgrep = function (str) {
   if (!str) {
     return this;
   }
@@ -542,10 +569,10 @@ Mocha.prototype.fgrep = function(str) {
  * // Given embedded test `it('only-this-test')`...
  * mocha.grep('/^only-this-test$/');    // NO! Use `.only()` to do this!
  */
-Mocha.prototype.grep = function(re) {
+Mocha.prototype.grep = function (re) {
   if (utils.isString(re)) {
     // extract args if it's regex-like, i.e: [string, pattern, flag]
-    var arg = re.match(/^\/(.*)\/(g|i|)$|.*/);
+    var arg = re.match(/^\/(.*)\/([gimy]{0,4})$|.*/);
     this.options.grep = new RegExp(arg[1] || arg[0], arg[2]);
   } else {
     this.options.grep = re;
@@ -565,7 +592,7 @@ Mocha.prototype.grep = function(re) {
  * // Select tests whose full title does *not* contain `"match"`, ignoring case
  * mocha.grep(/match/i).invert();
  */
-Mocha.prototype.invert = function() {
+Mocha.prototype.invert = function () {
   this.options.invert = true;
   return this;
 };
@@ -579,7 +606,7 @@ Mocha.prototype.invert = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.checkLeaks = function(checkLeaks) {
+Mocha.prototype.checkLeaks = function (checkLeaks) {
   this.options.checkLeaks = checkLeaks !== false;
   return this;
 };
@@ -594,7 +621,7 @@ Mocha.prototype.checkLeaks = function(checkLeaks) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.cleanReferencesAfterRun = function(cleanReferencesAfterRun) {
+Mocha.prototype.cleanReferencesAfterRun = function (cleanReferencesAfterRun) {
   this._cleanReferencesAfterRun = cleanReferencesAfterRun !== false;
   return this;
 };
@@ -604,7 +631,7 @@ Mocha.prototype.cleanReferencesAfterRun = function(cleanReferencesAfterRun) {
  * It also removes function references to tests functions and hooks, so variables trapped in closures can be cleaned by the garbage collector.
  * @public
  */
-Mocha.prototype.dispose = function() {
+Mocha.prototype.dispose = function () {
   if (this._state === mochaStates.RUNNING) {
     throw createMochaInstanceAlreadyRunningError(
       'Cannot dispose while the mocha instance is still running tests.'
@@ -625,7 +652,7 @@ Mocha.prototype.dispose = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.fullTrace = function(fullTrace) {
+Mocha.prototype.fullTrace = function (fullTrace) {
   this.options.fullTrace = fullTrace !== false;
   return this;
 };
@@ -638,7 +665,7 @@ Mocha.prototype.fullTrace = function(fullTrace) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.growl = function() {
+Mocha.prototype.growl = function () {
   this.options.growl = this.isGrowlCapable();
   if (!this.options.growl) {
     var detail = utils.isBrowser()
@@ -687,11 +714,11 @@ Mocha.prototype._growl = growl.notify;
  * // Specify variables to be expected in global scope
  * mocha.global(['jQuery', 'MyLib']);
  */
-Mocha.prototype.global = function(global) {
+Mocha.prototype.global = function (global) {
   this.options.global = (this.options.global || [])
     .concat(global)
     .filter(Boolean)
-    .filter(function(elt, idx, arr) {
+    .filter(function (elt, idx, arr) {
       return arr.indexOf(elt) === idx;
     });
   return this;
@@ -708,7 +735,7 @@ Mocha.prototype.globals = Mocha.prototype.global;
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.color = function(color) {
+Mocha.prototype.color = function (color) {
   this.options.color = color !== false;
   return this;
 };
@@ -723,7 +750,7 @@ Mocha.prototype.color = function(color) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.inlineDiffs = function(inlineDiffs) {
+Mocha.prototype.inlineDiffs = function (inlineDiffs) {
   this.options.inlineDiffs = inlineDiffs !== false;
   return this;
 };
@@ -737,7 +764,7 @@ Mocha.prototype.inlineDiffs = function(inlineDiffs) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.diff = function(diff) {
+Mocha.prototype.diff = function (diff) {
   this.options.diff = diff !== false;
   return this;
 };
@@ -765,7 +792,7 @@ Mocha.prototype.diff = function(diff) {
  * // Same as above but using string argument
  * mocha.timeout('1s');
  */
-Mocha.prototype.timeout = function(msecs) {
+Mocha.prototype.timeout = function (msecs) {
   this.suite.timeout(msecs);
   return this;
 };
@@ -784,7 +811,7 @@ Mocha.prototype.timeout = function(msecs) {
  * // Allow any failed test to retry one more time
  * mocha.retries(1);
  */
-Mocha.prototype.retries = function(retry) {
+Mocha.prototype.retries = function (retry) {
   this.suite.retries(retry);
   return this;
 };
@@ -806,7 +833,7 @@ Mocha.prototype.retries = function(retry) {
  * // Same as above but using string argument
  * mocha.slow('0.5s');
  */
-Mocha.prototype.slow = function(msecs) {
+Mocha.prototype.slow = function (msecs) {
   this.suite.slow(msecs);
   return this;
 };
@@ -820,7 +847,7 @@ Mocha.prototype.slow = function(msecs) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.asyncOnly = function(asyncOnly) {
+Mocha.prototype.asyncOnly = function (asyncOnly) {
   this.options.asyncOnly = asyncOnly !== false;
   return this;
 };
@@ -832,7 +859,7 @@ Mocha.prototype.asyncOnly = function(asyncOnly) {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.noHighlighting = function() {
+Mocha.prototype.noHighlighting = function () {
   this.options.noHighlighting = true;
   return this;
 };
@@ -846,7 +873,7 @@ Mocha.prototype.noHighlighting = function() {
  * @return {Mocha} this
  * @chainable
  */
-Mocha.prototype.allowUncaught = function(allowUncaught) {
+Mocha.prototype.allowUncaught = function (allowUncaught) {
   this.options.allowUncaught = allowUncaught !== false;
   return this;
 };
@@ -868,6 +895,34 @@ Mocha.prototype.delay = function delay() {
   return this;
 };
 
+/**
+ * Enables or disables running tests in dry-run mode.
+ *
+ * @public
+ * @see [CLI option](../#-dry-run)
+ * @param {boolean} [dryRun=true] - Whether to activate dry-run mode.
+ * @return {Mocha} this
+ * @chainable
+ */
+Mocha.prototype.dryRun = function (dryRun) {
+  this.options.dryRun = dryRun !== false;
+  return this;
+};
+
+/**
+ * Fails test run if no tests encountered with exit-code 1.
+ *
+ * @public
+ * @see [CLI option](../#-fail-zero)
+ * @param {boolean} [failZero=true] - Whether to fail test run.
+ * @return {Mocha} this
+ * @chainable
+ */
+Mocha.prototype.failZero = function (failZero) {
+  this.options.failZero = failZero !== false;
+  return this;
+};
+
 /**
  * Causes tests marked `only` to fail the suite.
  *
@@ -877,7 +932,7 @@ Mocha.prototype.delay = function delay() {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.forbidOnly = function(forbidOnly) {
+Mocha.prototype.forbidOnly = function (forbidOnly) {
   this.options.forbidOnly = forbidOnly !== false;
   return this;
 };
@@ -891,7 +946,7 @@ Mocha.prototype.forbidOnly = function(forbidOnly) {
  * @returns {Mocha} this
  * @chainable
  */
-Mocha.prototype.forbidPending = function(forbidPending) {
+Mocha.prototype.forbidPending = function (forbidPending) {
   this.options.forbidPending = forbidPending !== false;
   return this;
 };
@@ -900,7 +955,7 @@ Mocha.prototype.forbidPending = function(forbidPending) {
  * Throws an error if mocha is in the wrong state to be able to transition to a "running" state.
  * @private
  */
-Mocha.prototype._guardRunningStateTransition = function() {
+Mocha.prototype._guardRunningStateTransition = function () {
   if (this._state === mochaStates.RUNNING) {
     throw createMochaInstanceAlreadyRunningError(
       'Mocha instance is currently running tests, cannot start a next test run until this one is done',
@@ -959,7 +1014,7 @@ Object.defineProperty(Mocha.prototype, 'version', {
  * // exit with non-zero status if there were test failures
  * mocha.run(failures => process.exitCode = failures ? 1 : 0);
  */
-Mocha.prototype.run = function(fn) {
+Mocha.prototype.run = function (fn) {
   this._guardRunningStateTransition();
   this._state = mochaStates.RUNNING;
   if (this._previousRunner) {
@@ -973,8 +1028,10 @@ Mocha.prototype.run = function(fn) {
   var options = this.options;
   options.files = this.files;
   const runner = new this._runnerClass(suite, {
+    cleanReferencesAfterRun: this._cleanReferencesAfterRun,
     delay: options.delay,
-    cleanReferencesAfterRun: this._cleanReferencesAfterRun
+    dryRun: options.dryRun,
+    failZero: options.failZero
   });
   createStatsCollector(runner);
   var reporter = new this._reporter(runner, options);
@@ -1260,9 +1317,10 @@ Mocha.prototype.hasGlobalSetupFixtures = function hasGlobalSetupFixtures() {
  * @public
  * @returns {boolean}
  */
-Mocha.prototype.hasGlobalTeardownFixtures = function hasGlobalTeardownFixtures() {
-  return Boolean(this.options.globalTeardown.length);
-};
+Mocha.prototype.hasGlobalTeardownFixtures =
+  function hasGlobalTeardownFixtures() {
+    return Boolean(this.options.globalTeardown.length);
+  };
 
 /**
  * An alternative way to define root hooks that works with parallel runs.
@@ -1299,7 +1357,7 @@ Mocha.prototype.hasGlobalTeardownFixtures = function hasGlobalTeardownFixtures()
  * A (sync) function to assert a user-supplied plugin implementation is valid.
  *
  * Defined in a {@link PluginDefinition}.
- 
+
  * @callback PluginValidator
  * @param {*} value - Value to check
  * @this {PluginDefinition}
