@@ -7,9 +7,10 @@ import globals from 'rollup-plugin-node-globals';
 import {babel} from '@rollup/plugin-babel';
 
 // Debugging tools
-import visualizer from 'rollup-plugin-visualizer';
+import {visualizer} from 'rollup-plugin-visualizer';
 
 import pickFromPackageJson from './scripts/pick-from-package-json';
+import {version} from './package.json';
 
 const config = {
   input: './browser-entry.js',
@@ -17,7 +18,9 @@ const config = {
     file: './mocha.js',
     format: 'umd',
     sourcemap: true,
-    name: 'mocha'
+    name: 'mocha',
+    banner: `// mocha@${version} transpiled to javascript ES5`,
+    intro: 'var regeneratorRuntime;'
   },
   plugins: [
     json(),
