@@ -1,16 +1,16 @@
+/* global BigInt */
 'use strict';
 
 var utils = require('../../lib/utils');
-const errors = require('../../lib/errors');
 var sinon = require('sinon');
 
-describe('lib/utils', function() {
-  afterEach(function() {
+describe('lib/utils', function () {
+  afterEach(function () {
     sinon.restore();
   });
 
-  describe('clean()', function() {
-    it('should remove the wrapping function declaration', function() {
+  describe('clean()', function () {
+    it('should remove the wrapping function declaration', function () {
       expect(
         utils.clean('function  (one, two, three)  {\n//code\n}'),
         'to be',
@@ -18,7 +18,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle newlines in the function declaration', function() {
+    it('should handle newlines in the function declaration', function () {
       expect(
         utils.clean('function  (one, two, three)\n  {\n//code\n}'),
         'to be',
@@ -26,7 +26,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should remove space character indentation from the function body', function() {
+    it('should remove space character indentation from the function body', function () {
       expect(
         utils.clean('  //line1\n    //line2'),
         'to be',
@@ -34,7 +34,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should remove tab character indentation from the function body', function() {
+    it('should remove tab character indentation from the function body', function () {
       expect(
         utils.clean('\t//line1\n\t\t//line2'),
         'to be',
@@ -42,11 +42,11 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle functions with tabs in their declarations', function() {
+    it('should handle functions with tabs in their declarations', function () {
       expect(utils.clean('function\t(\t)\t{\n//code\n}'), 'to be', '//code');
     });
 
-    it('should handle named functions without space after name', function() {
+    it('should handle named functions without space after name', function () {
       expect(
         utils.clean('function withName() {\n//code\n}'),
         'to be',
@@ -54,7 +54,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle named functions with space after name', function() {
+    it('should handle named functions with space after name', function () {
       expect(
         utils.clean('function withName () {\n//code\n}'),
         'to be',
@@ -62,11 +62,11 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle functions with no space between the end and the closing brace', function() {
+    it('should handle functions with no space between the end and the closing brace', function () {
       expect(utils.clean('function() {/*code*/}'), 'to be', '/*code*/');
     });
 
-    it('should handle functions with parentheses in the same line', function() {
+    it('should handle functions with parentheses in the same line', function () {
       expect(
         utils.clean('function() { if (true) { /* code */ } }'),
         'to be',
@@ -74,16 +74,16 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle empty functions', function() {
+    it('should handle empty functions', function () {
       expect(utils.clean('function() {}'), 'to be', '');
     });
 
-    it('should format a single line test function', function() {
+    it('should format a single line test function', function () {
       var fn = ['function () {', '  var a = 1;', '}'].join('\n');
       expect(utils.clean(fn), 'to be', 'var a = 1;');
     });
 
-    it('should format a multi line test indented with spaces', function() {
+    it('should format a multi line test indented with spaces', function () {
       // and no new lines after curly braces, shouldn't matter
       var fn = [
         'function(){  var a = 1;',
@@ -94,7 +94,7 @@ describe('lib/utils', function() {
       expect(utils.clean(fn), 'to be', 'var a = 1;\n  var b = 2;\nvar c = 3;');
     });
 
-    it('should format a multi line test indented with tabs', function() {
+    it('should format a multi line test indented with tabs', function () {
       var fn = [
         'function (arg1, arg2)   {',
         '\tif (true) {',
@@ -105,7 +105,7 @@ describe('lib/utils', function() {
       expect(utils.clean(fn), 'to be', 'if (true) {\n\tvar a = 1;\n}');
     });
 
-    it('should format functions saved in windows style - spaces', function() {
+    it('should format functions saved in windows style - spaces', function () {
       var fn = [
         'function (one) {',
         '   do {',
@@ -116,7 +116,7 @@ describe('lib/utils', function() {
       expect(utils.clean(fn), 'to be', 'do {\n "nothing";\n} while (false);');
     });
 
-    it('should format functions saved in windows style - tabs', function() {
+    it('should format functions saved in windows style - tabs', function () {
       var fn = [
         'function ( )   {',
         '\tif (false) {',
@@ -133,21 +133,21 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should format es6 arrow functions', function() {
+    it('should format es6 arrow functions', function () {
       var fn = ['() => {', '  var a = 1;', '}'].join('\n');
       expect(utils.clean(fn), 'to be', 'var a = 1;');
     });
 
-    it('should format es6 arrow functions with implicit return', function() {
+    it('should format es6 arrow functions with implicit return', function () {
       var fn = '() => foo()';
       expect(utils.clean(fn), 'to be', 'foo()');
     });
   });
 
-  describe('stringify()', function() {
+  describe('stringify()', function () {
     var stringify = utils.stringify;
 
-    it('should return an object representation of a string created with a String constructor', function() {
+    it('should return an object representation of a string created with a String constructor', function () {
       /* eslint no-new-wrappers: off */
       expect(
         stringify(new String('foo')),
@@ -156,7 +156,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should return Buffer with .toJSON representation', function() {
+    it('should return Buffer with .toJSON representation', function () {
       expect(stringify(Buffer.from([0x01])), 'to be', '[\n  1\n]');
       expect(stringify(Buffer.from([0x01, 0x02])), 'to be', '[\n  1\n  2\n]');
 
@@ -167,7 +167,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should return Date object with .toISOString() + string prefix', function() {
+    it('should return Date object with .toISOString() + string prefix', function () {
       expect(
         stringify(new Date(0)),
         'to be',
@@ -178,7 +178,7 @@ describe('lib/utils', function() {
       expect(stringify(date), 'to be', '[Date: ' + date.toISOString() + ']');
     });
 
-    it('should return invalid Date object with .toString() + string prefix', function() {
+    it('should return invalid Date object with .toString() + string prefix', function () {
       expect(
         stringify(new Date('')),
         'to be',
@@ -186,28 +186,35 @@ describe('lib/utils', function() {
       );
     });
 
-    describe('#Number', function() {
-      it('should show the handle -0 situations', function() {
+    describe('#Number', function () {
+      it('should show the handle -0 situations', function () {
         expect(stringify(-0), 'to be', '-0');
         expect(stringify(0), 'to be', '0');
         expect(stringify('-0'), 'to be', '"-0"');
       });
 
-      it('should work well with `NaN` and `Infinity`', function() {
+      it('should work well with `NaN` and `Infinity`', function () {
         expect(stringify(NaN), 'to be', 'NaN');
         expect(stringify(Infinity), 'to be', 'Infinity');
         expect(stringify(-Infinity), 'to be', '-Infinity');
       });
 
-      it('floats and ints', function() {
+      it('floats and ints', function () {
         expect(stringify(1), 'to be', '1');
         expect(stringify(1.2), 'to be', '1.2');
         expect(stringify(1e9), 'to be', '1000000000');
       });
+
+      if (typeof BigInt === 'function') {
+        it('should work with bigints when possible', function () {
+          expect(stringify(BigInt(1)), 'to be', '1n');
+          expect(stringify(BigInt(2)), 'to be', '2n');
+        });
+      }
     });
 
-    describe('canonicalize example', function() {
-      it('should represent the actual full result', function() {
+    describe('canonicalize example', function () {
+      it('should represent the actual full result', function () {
         var expected = {
           str: 'string',
           int: 90,
@@ -217,7 +224,7 @@ describe('lib/utils', function() {
           undef: undefined,
           regex: /^[a-z|A-Z]/,
           date: new Date(0),
-          func: function() {},
+          func: function () {},
           infi: Infinity,
           nan: NaN,
           zero: -0,
@@ -283,14 +290,14 @@ describe('lib/utils', function() {
       });
     });
 
-    it('should canonicalize the object', function() {
+    it('should canonicalize the object', function () {
       var travis = {name: 'travis', age: 24};
       var travis2 = {age: 24, name: 'travis'};
 
       expect(stringify(travis), 'to be', stringify(travis2));
     });
 
-    it('should handle circular structures in objects', function() {
+    it('should handle circular structures in objects', function () {
       var travis = {name: 'travis'};
       travis.whoami = travis;
 
@@ -301,22 +308,22 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle circular structures in arrays', function() {
+    it('should handle circular structures in arrays', function () {
       var travis = ['travis'];
       travis.push(travis);
 
       expect(stringify(travis), 'to be', '[\n  "travis"\n  [Circular]\n]');
     });
 
-    it('should handle circular structures in functions', function() {
-      var travis = function() {};
+    it('should handle circular structures in functions', function () {
+      var travis = function () {};
       travis.fn = travis;
 
       expect(stringify(travis), 'to be', '{\n  "fn": [Circular]\n}');
     });
 
-    it('should handle various non-undefined, non-null, non-object, non-array, non-date, and non-function values', function() {
-      var regexp = new RegExp('(?:)');
+    it('should handle various non-undefined, non-null, non-object, non-array, non-date, and non-function values', function () {
+      var regexp = /(?:)/;
       var regExpObj = {regexp: regexp};
       var regexpString = '/(?:)/';
 
@@ -363,7 +370,7 @@ describe('lib/utils', function() {
       expect(stringify(nullValue), 'to be', nullString);
     });
 
-    it('should handle arrays', function() {
+    it('should handle arrays', function () {
       var array = ['dave', 'dave', 'dave', 'dave'];
       var arrayObj = {array: array};
       var arrayString = '    "dave"\n    "dave"\n    "dave"\n    "dave"';
@@ -380,8 +387,8 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle functions', function() {
-      var fn = function() {};
+    it('should handle functions', function () {
+      var fn = function () {};
       var fnObj = {fn: fn};
       var fnString = '[Function]';
 
@@ -389,40 +396,40 @@ describe('lib/utils', function() {
       expect(stringify(fn), 'to be', '[Function]');
     });
 
-    it('should handle empty objects', function() {
+    it('should handle empty objects', function () {
       expect(stringify({}), 'to be', '{}');
       expect(stringify({foo: {}}), 'to be', '{\n  "foo": {}\n}');
     });
 
-    it('should handle empty arrays', function() {
+    it('should handle empty arrays', function () {
       expect(stringify([]), 'to be', '[]');
       expect(stringify({foo: []}), 'to be', '{\n  "foo": []\n}');
     });
 
-    it('should handle non-empty arrays', function() {
+    it('should handle non-empty arrays', function () {
       expect(stringify(['a', 'b', 'c']), 'to be', '[\n  "a"\n  "b"\n  "c"\n]');
     });
 
-    it('should handle empty functions (with no properties)', function() {
+    it('should handle empty functions (with no properties)', function () {
       expect(
-        stringify(function() {}),
+        stringify(function () {}),
         'to be',
         '[Function]'
       );
       expect(
-        stringify({foo: function() {}}),
+        stringify({foo: function () {}}),
         'to be',
         '{\n  "foo": [Function]\n}'
       );
       expect(
-        stringify({foo: function() {}, bar: 'baz'}),
+        stringify({foo: function () {}, bar: 'baz'}),
         'to be',
         '{\n  "bar": "baz"\n  "foo": [Function]\n}'
       );
     });
 
-    it('should handle functions w/ properties', function() {
-      var fn = function() {};
+    it('should handle functions w/ properties', function () {
+      var fn = function () {};
       fn.bar = 'baz';
       expect(stringify(fn), 'to be', '{\n  "bar": "baz"\n}');
       expect(
@@ -432,7 +439,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle undefined values', function() {
+    it('should handle undefined values', function () {
       expect(
         stringify({foo: undefined}),
         'to be',
@@ -446,7 +453,7 @@ describe('lib/utils', function() {
       expect(stringify(), 'to be', '[undefined]');
     });
 
-    it('should recurse', function() {
+    it('should recurse', function () {
       expect(
         stringify({foo: {bar: {baz: {quux: {herp: 'derp'}}}}}),
         'to be',
@@ -454,11 +461,11 @@ describe('lib/utils', function() {
       );
     });
 
-    it('might get confusing', function() {
+    it('might get confusing', function () {
       expect(stringify(null), 'to be', '[null]');
     });
 
-    it('should not freak out if it sees a primitive twice', function() {
+    it('should not freak out if it sees a primitive twice', function () {
       expect(
         stringify({foo: null, bar: null}),
         'to be',
@@ -471,7 +478,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should stringify dates', function() {
+    it('should stringify dates', function () {
       var date = new Date(0);
       expect(stringify(date), 'to be', '[Date: 1970-01-01T00:00:00.000Z]');
       expect(
@@ -481,7 +488,7 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should handle object without an Object prototype', function() {
+    it('should handle object without an Object prototype', function () {
       var a;
       if (Object.create) {
         a = Object.create(null);
@@ -495,7 +502,7 @@ describe('lib/utils', function() {
 
     // In old version node.js, Symbol is not available by default.
     if (typeof global.Symbol === 'function') {
-      it('should handle Symbol', function() {
+      it('should handle Symbol', function () {
         var symbol = Symbol('value');
         expect(stringify(symbol), 'to match', /^Symbol\(value\)/);
         expect(
@@ -506,7 +513,7 @@ describe('lib/utils', function() {
       });
     }
 
-    it('should handle length properties that cannot be coerced to a number', function() {
+    it('should handle length properties that cannot be coerced to a number', function () {
       expect(
         stringify({length: {nonBuiltinProperty: 0}}),
         'to be',
@@ -520,15 +527,15 @@ describe('lib/utils', function() {
     });
   });
 
-  describe('type()', function() {
+  describe('type()', function () {
     /* eslint no-extend-native: off */
 
     var type = utils.type;
     var toString = Object.prototype.toString;
 
-    beforeEach(function() {
+    beforeEach(function () {
       // some JS engines such as PhantomJS 1.x exhibit this behavior
-      Object.prototype.toString = function() {
+      Object.prototype.toString = function () {
         if (this === global) {
           return '[object DOMWindow]';
         }
@@ -536,7 +543,7 @@ describe('lib/utils', function() {
       };
     });
 
-    it('should recognize various types', function() {
+    it('should recognize various types', function () {
       expect(type({}), 'to be', 'object');
       expect(type([]), 'to be', 'array');
       expect(type(1), 'to be', 'number');
@@ -562,27 +569,27 @@ describe('lib/utils', function() {
       );
     });
 
-    describe('when toString on null or undefined stringifies window', function() {
-      it('should recognize null and undefined', function() {
+    describe('when toString on null or undefined stringifies window', function () {
+      it('should recognize null and undefined', function () {
         expect(type(null), 'to be', 'null');
         expect(type(undefined), 'to be', 'undefined');
       });
     });
 
-    afterEach(function() {
+    afterEach(function () {
       Object.prototype.toString = toString;
     });
   });
 
-  describe('canonicalType()', function() {
+  describe('canonicalType()', function () {
     /* eslint no-extend-native: off */
 
     var type = utils.canonicalType;
     var toString = Object.prototype.toString;
 
-    beforeEach(function() {
+    beforeEach(function () {
       // some JS engines such as PhantomJS 1.x exhibit this behavior
-      Object.prototype.toString = function() {
+      Object.prototype.toString = function () {
         if (this === global) {
           return '[object DOMWindow]';
         }
@@ -590,7 +597,7 @@ describe('lib/utils', function() {
       };
     });
 
-    it('should recognize various types', function() {
+    it('should recognize various types', function () {
       expect(type({}), 'to be', 'object');
       expect(type([]), 'to be', 'array');
       expect(type(1), 'to be', 'number');
@@ -604,44 +611,44 @@ describe('lib/utils', function() {
       expect(type(true), 'to be', 'boolean');
     });
 
-    describe('when toString on null or undefined stringifies window', function() {
-      it('should recognize null and undefined', function() {
+    describe('when toString on null or undefined stringifies window', function () {
+      it('should recognize null and undefined', function () {
         expect(type(null), 'to be', 'null');
         expect(type(undefined), 'to be', 'undefined');
       });
     });
 
-    afterEach(function() {
+    afterEach(function () {
       Object.prototype.toString = toString;
     });
   });
 
-  describe('isPromise()', function() {
-    it('should return true if the value is Promise-ish', function() {
+  describe('isPromise()', function () {
+    it('should return true if the value is Promise-ish', function () {
       expect(
         utils.isPromise({
-          then: function() {}
+          then: function () {}
         }),
         'to be',
         true
       );
     });
 
-    it('should return false if the value is not an object', function() {
+    it('should return false if the value is not an object', function () {
       expect(utils.isPromise(1), 'to be', false);
     });
 
-    it('should return false if the value is an object w/o a "then" function', function() {
+    it('should return false if the value is an object w/o a "then" function', function () {
       expect(utils.isPromise({}), 'to be', false);
     });
 
-    it('should return false if the object is null', function() {
+    it('should return false if the object is null', function () {
       expect(utils.isPromise(null), 'to be', false);
     });
   });
 
-  describe('escape()', function() {
-    it('replaces the usual xml suspects', function() {
+  describe('escape()', function () {
+    it('replaces the usual xml suspects', function () {
       expect(utils.escape('<a<bc<d<'), 'to be', '&#x3C;a&#x3C;bc&#x3C;d&#x3C;');
       expect(utils.escape('>a>bc>d>'), 'to be', '&#x3E;a&#x3E;bc&#x3E;d&#x3E;');
       expect(utils.escape('"a"bc"d"'), 'to be', '&#x22;a&#x22;bc&#x22;d&#x22;');
@@ -651,7 +658,7 @@ describe('lib/utils', function() {
       expect(utils.escape('&amp;&lt;'), 'to be', '&#x26;amp;&#x26;lt;');
     });
 
-    it('replaces invalid xml characters', function() {
+    it('replaces invalid xml characters', function () {
       expect(
         utils.escape('\x1B[32mfoo\x1B[0m'),
         'to be',
@@ -662,36 +669,18 @@ describe('lib/utils', function() {
     });
   });
 
-  describe('sQuote()', function() {
-    var str = 'xxx';
-
-    it('should return its input as string wrapped in single quotes', function() {
-      var expected = "'xxx'";
-      expect(utils.sQuote(str), 'to be', expected);
-    });
-  });
-
-  describe('dQuote()', function() {
-    var str = 'xxx';
-
-    it('should return its input as string wrapped in double quotes', function() {
-      var expected = '"xxx"';
-      expect(utils.dQuote(str), 'to be', expected);
-    });
-  });
-
-  describe('createMap()', function() {
-    it('should return an object with a null prototype', function() {
+  describe('createMap()', function () {
+    it('should return an object with a null prototype', function () {
       expect(Object.getPrototypeOf(utils.createMap()), 'to be', null);
     });
 
-    it('should add props to the object', function() {
+    it('should add props to the object', function () {
       expect(utils.createMap({foo: 'bar'}), 'to exhaustively satisfy', {
         foo: 'bar'
       });
     });
 
-    it('should add props from all object parameters to the object', function() {
+    it('should add props from all object parameters to the object', function () {
       expect(
         utils.createMap({foo: 'bar'}, {bar: 'baz'}),
         'to exhaustively satisfy',
@@ -700,12 +689,12 @@ describe('lib/utils', function() {
     });
   });
 
-  describe('slug()', function() {
-    it('should convert the string to lowercase', function() {
+  describe('slug()', function () {
+    it('should convert the string to lowercase', function () {
       expect(utils.slug('FOO'), 'to be', 'foo');
     });
 
-    it('should convert whitespace to dashes', function() {
+    it('should convert whitespace to dashes', function () {
       expect(
         utils.slug('peanut butter\nand\tjelly'),
         'to be',
@@ -713,18 +702,18 @@ describe('lib/utils', function() {
       );
     });
 
-    it('should strip non-alphanumeric and non-dash characters', function() {
+    it('should strip non-alphanumeric and non-dash characters', function () {
       expect(utils.slug('murder-hornets!!'), 'to be', 'murder-hornets');
     });
 
-    it('should disallow consecutive dashes', function() {
+    it('should disallow consecutive dashes', function () {
       expect(utils.slug('poppies & fritz'), 'to be', 'poppies-fritz');
     });
   });
 
-  describe('castArray()', function() {
-    describe('when provided an array value', function() {
-      it('should return a copy of the array', function() {
+  describe('castArray()', function () {
+    describe('when provided an array value', function () {
+      it('should return a copy of the array', function () {
         const v = ['foo', 'bar', 'baz'];
         expect(utils.castArray(v), 'to equal', ['foo', 'bar', 'baz']).and(
           'not to be',
@@ -733,9 +722,9 @@ describe('lib/utils', function() {
       });
     });
 
-    describe('when provided an "arguments" value', function() {
-      it('should return an array containing the arguments', function() {
-        (function() {
+    describe('when provided an "arguments" value', function () {
+      it('should return an array containing the arguments', function () {
+        (function () {
           expect(utils.castArray(arguments), 'to equal', [
             'foo',
             'bar',
@@ -745,79 +734,34 @@ describe('lib/utils', function() {
       });
     });
 
-    describe('when provided an object', function() {
-      it('should return an array containing the object only', function() {
+    describe('when provided an object', function () {
+      it('should return an array containing the object only', function () {
         const v = {foo: 'bar'};
         expect(utils.castArray(v), 'to equal', [v]);
       });
     });
 
-    describe('when provided no parameters', function() {
-      it('should return an empty array', function() {
+    describe('when provided no parameters', function () {
+      it('should return an empty array', function () {
         expect(utils.castArray(), 'to equal', []);
       });
     });
 
-    describe('when provided a primitive value', function() {
-      it('should return an array containing the primitive value only', function() {
+    describe('when provided a primitive value', function () {
+      it('should return an array containing the primitive value only', function () {
         expect(utils.castArray('butts'), 'to equal', ['butts']);
       });
     });
 
-    describe('when provided null', function() {
-      it('should return an array containing a null value only', function() {
+    describe('when provided null', function () {
+      it('should return an array containing a null value only', function () {
         expect(utils.castArray(null), 'to equal', [null]);
       });
     });
   });
 
-  describe('lookupFiles()', function() {
-    beforeEach(function() {
-      sinon.stub(errors, 'deprecate');
-    });
-
-    describe('when run in Node.js', function() {
-      before(function() {
-        if (process.browser) {
-          return this.skip();
-        }
-      });
-
-      beforeEach(function() {
-        sinon.stub(utils, 'isBrowser').returns(false);
-        sinon.stub(require('../../lib/cli'), 'lookupFiles').returns([]);
-      });
-
-      it('should print a deprecation message', function() {
-        utils.lookupFiles();
-        expect(errors.deprecate, 'was called once');
-      });
-
-      it('should delegate to new location of lookupFiles()', function() {
-        utils.lookupFiles(['foo']);
-        expect(
-          require('../../lib/cli').lookupFiles,
-          'to have a call satisfying',
-          [['foo']]
-        ).and('was called once');
-      });
-    });
-
-    describe('when run in browser', function() {
-      beforeEach(function() {
-        sinon.stub(utils, 'isBrowser').returns(true);
-      });
-
-      it('should throw', function() {
-        expect(() => utils.lookupFiles(['foo']), 'to throw', {
-          code: 'ERR_MOCHA_UNSUPPORTED'
-        });
-      });
-    });
-  });
-
-  describe('uniqueID()', function() {
-    it('should return a non-empty string', function() {
+  describe('uniqueID()', function () {
+    it('should return a non-empty string', function () {
       expect(utils.uniqueID(), 'to be a string').and('not to be empty');
     });
   });
